==> app11_08_2021-4:52pm.zip: app/api/deposits/testing.php <==
<?php

    include("../../../settings/dbconn.php");
    include("../../../settings/utils.php");
    include("../../hooks/google2fa/autoload.php");
    use PragmaRX\Google2FA\Google2FA;
    //AQUI SE CREA LA CREDENCIAL PRIVADA
    $google2fa = new Google2FA();
    $secretKey = $google2fa->generateSecretKey(32);
    $qrCodeUrl = $google2fa->getQRCodeUrl(
        "AFX Trade",
        "developer1@totalsoftware.com.ve",
        $secretKey
    );
    echo($qrCodeUrl);
    
    //AQUI SE VALIDA LA EL BETA
    //$valid = $google2fa->verifyKey('HECYGADSOIQIJADZ', '289379', 0);
    //var_dump($valid);
    
    
    
    
    // app/api/deposits/testing
    /*
    header("Content-Type:application/json");
    include("../../../settings/dbconn.php");
    include("../../../settings/utils.php");
    $timezone = date_default_timezone_get();
   // date_default_timezone_set('Etc/UTC');
   $key = "172.28.77.8"."afxtrade"."AA2LtO6bIhov0exjxsX";
   echo encrypt("AA2LtO6bIhov0exjxsX",$key);
   function encrypt($string, $key) {
        $result = '';
        for($i=0; $i<strlen($string); $i++) {
            $char = substr($string, $i, 1);
            $keychar = substr($key, ($i % strlen($key))-1, 1);
            $char = chr(ord($char)+ord($keychar));
            $result.=$char;
        }
        return base64_encode($result);
    }
    die();
   */
   /*
   $url = "https://api.trongrid.io/v1/accounts/TL8TzvMqWWQG1G4d8D2c8vHTzPeSzjMBcr/transactions/trc20";
   function queryPublic($url, $type=false, array $request = array()){
    //Inicializamos el protocolo
    $curl = curl_init();
    curl_setopt_array($curl, array(
        CURLOPT_SSL_VERIFYPEER => true,
        CURLOPT_SSL_VERIFYHOST => 2,
        CURLOPT_USERAGENT => 'TCV PHP API Agent',
        CURLOPT_POST => true,
        CURLOPT_RETURNTRANSFER => true,
        CURLOPT_CONNECTTIMEOUT => 20,
        CURLOPT_TIMEOUT => 300)
    );

    // Parametros
    $postdata = http_build_query($request, '', '&');

    // llave de la api con su version
    $path = $url;
    // make request
    curl_setopt($curl, CURLOPT_URL, $url);
    curl_setopt($curl, CURLOPT_POSTFIELDS, $postdata);
    curl_setopt($curl, CURLOPT_HTTPHEADER, array());

    //si el type es true la llamada sera GET
    if($type){
        curl_setopt($curl, CURLOPT_URL, $url."?" . $postdata);
        curl_setopt($curl, CURLOPT_POST, false);
        curl_setopt($curl, CURLOPT_CUSTOMREQUEST, 'GET');
    }

    //Ejecutamos la llamada
    $result = curl_exec($curl);
    if ($result === false) {
        throw new \Exception('CURL error: ' . curl_error($curl));
    }

    // Comprueba el código de estado HTTP
    if (!curl_errno($curl)) {
        switch ($httpCode = curl_getinfo($curl, CURLINFO_HTTP_CODE)) {
                case 200: # OK
                break;
            default:
                echo 'HTTP code: ', $httpCode, "\n";
        }
    }
    $result = json_decode($result, true);

    curl_close($curl);

    return $result;
}
var_dump(queryPublic($url,true));
die();
   
   */
   
   
   /*
    function getUTCOffset($timezone, $colon=true)
    {
      $dtz = new DateTimeZone($timezone);
      $offset = $dtz->getOffset(new DateTime());
      $format=($colon)?'%+03d:%02u':'%+03d%02u';
    
      return sprintf($format, $offset / 3600, abs($offset) % 3600 / 60);
    }
    
    echo $timezone."\n";
    $zona = new DateTimeZone($timezone); 
    $fecha = microtime(true)+$zona->getOffset(new DateTime());
    echo $dateW = date("d/m/Y",$fecha)." - ".date("h:i:s a",$fecha)."\n";
    echo getUTCOffset('America/Caracas')."\n";
    echo getUTCOffset('Europe/Madrid', false)."\n";
    
    $file = "uploads/payments/35905.png";
    $zona = new DateTimeZone('America/Caracas'); 
    $fecha = microtime(true)+$zona->getOffset(new DateTime());
    $dateW = date("d/m/Y",$fecha)." - ".date("h:i:s a",$fecha);
    $watermark = $dateW. " https://afx.trade #".$txid;
    $save =  "../../../uploads/payments/35905.png";
    echo exif_imagetype("../../../uploads/payments/35905.png")."\n";
    echo (image_type_to_mime_type(exif_imagetype("../../../uploads/payments/35905.png")));
    addTextWatermark($file,$watermark,$save, "../../../");
    die();
    //include("../../../settings/utils.php");
    
    /***
     * getnewaddress asignar un label para identificar las direcciones ejemplo "afxusers" te permite trabajr multiples direcciones ("afxaddr")<-actual creados de prueba
     * getaddressesbylabel listar direcciones por label
     * listtransactions puedes filtrar solo las transacciones de la cuenta con ese "label"
     * sendtoaddress "address" amount ( "comment" "comment_to" subtractfeefromamount replaceable conf_target "estimate_mode") //Usable para retiros
     * gettransaction "txid" consultar una transacción. 
     * getbalance devuelve el saldo general de la billetera en todas sus direcciones.
     * */
    /*
    $nonce = generateNonce();
                    
                    // Llamamos a la api primerito
                    $request = array(
                        'banco'=>'0138',
                        'idBeneficiario'=>"V18184465",
                        'telefono'=>"4244445566",
                        'monto'=>(float)number_format(10000, 2, '.', ''),
                        'motivo'=>'Retiro AFX',
                        'canal'=>'23',
                    );
                    
                    $headers = array('Content-Type:application/json', 
                        "api-key: $BP_C2P_KEY", 
                        "api-signature: ".
                        (
                            generateApiSignature("/".$BP_VERSION_P2P."/pagos/p2p".$nonce.json_encode($request),$BP_C2P_KEY_SECRET)
                        ),
                        "nonce: ".$nonce,
                    );
                    // obtenemos respuesta
                    //$rest = queryApiBP($BP_URL_QA, "pagos/p2p", $BP_VERSION_P2P, "POST", $headers, $request);
                    //die(json_encode($rest));
    */
    /*
    function addTextWatermark($src, $watermark, $save=NULL) { 
         list($width, $height) = getimagesize($src);
         $image_color = imagecreatetruecolor($width, $height);
         $image_tmp = imagecreatetruecolor(740,50);
         $image = imagecreatefromjpeg($src);
         
         $logo = imagecreatefrompng('../../img/afx-logo.png');
         list($width2, $height2) = getimagesize('../../img/afx-logo.png');
         $txtcolor = imagecolorallocate($image_tmp, 255, 255, 255);
         $font = '../../fonts/roboto/Roboto-Black.ttf';
         $font_size = 20;
         
         imagecopyresampled($image_tmp, $logo, 25, 0, 0, -5, 60, 60, $width2, $height2);
         imagettftext($image_tmp, $font_size, 0, 90, 42.5, $txtcolor, $font, $watermark);
         
         $waterW = $width;
         $center = 0;
         if($waterW>740){
             $waterW=740;
             $center = ($width/2)-365;
         }
         
         
         
         imagecopyresampled($image_color, $image_tmp, $center, 0, 0, 0, $waterW, 50, 740, 50);
         imagesavealpha($image_color, true);
         
          $y =  rand(100, ($height-100));
         imagecopymerge($image,$image_color, 0, $y, 0, 0, $width, 60, 30);
         //imagecopyresampled($image_color, $image, 0, 0, 0, 0, $width, $height, $width, $height); 
         //imagestring($image_color, $font_size, 50, 350, $watermark, $txtcolor);
         if ($save<>'') {
            imagejpeg ($image_color, $save, 100); 
         } else {
             header('Content-Type: image/jpeg');
             imagejpeg($image, null, 100);
         }
         imagedestroy($image); 
         imagedestroy($image_color); 
    }*/
    /*
    function addTextWatermark($src, $watermark, $save=NULL,$url) { 
        list($width, $height) = getimagesize($src);
        $image_color = imagecreatetruecolor($width, $height);//Img base (marca de agua)
        $image_tmp = imagecreatetruecolor(740,50); //Marca de agua tamaño fijo
        $type = explode(".",$src);
        $type = strtoupper($type[1]);
        echo(var_dump(explode(".",$src)));
        die();
         //Se crea según su tipo
        switch($type){
            case 'JPG':
                $image = imagecreatefromjpeg($src); //img original
            break;
            case 'PNG':
                $image = imagecreatefrompng($src); //img original
            break;
            default :
                     
            break;
        }
         
        //Pinto el logo en el lado izquierdo e introduzco el texto a una imagen temporal.
        $logosrc = $url.'/img/afx-logo.png';
        $logo = imagecreatefrompng($logosrc);
        list($width2, $height2) = getimagesize($logosrc);
        $txtcolor = imagecolorallocate($image_tmp, 255, 255, 255);
        $font = $url.'/fonts/roboto/Roboto-Black.ttf';
        $font_size = 20;
        imagecopyresampled($image_tmp, $logo, 25, 0, 0, -5, 60, 60, $width2, $height2);
        imagettftext($image_tmp, $font_size, 0, 90, 42.5, $txtcolor, $font, $watermark);
         
        $waterW = $width;
        $center = 0;
         //Se calcula el tamaño de la imagen base (marca de agua) y se ubica la imagen creada en la marca de agua
        if($waterW>740){
            $waterW=740;
            $center = ($width/2)-365;
        }
        imagecopyresampled($image_color, $image_tmp, $center, 0, 0, 0, $waterW, 50, 740, 50);
        imagesavealpha($image_color, true);
         
        //Se Inserta la marca de agua a la imagen original del ancho completo y ubicación Y aleatroia sin llegar a los bordes (-100)
        $y =  rand(100, ($height-100));
        imagecopymerge($image,$image_color, 0, $y, 0, 0, $width, 60, 30);
        
         //Se guarda o no
        switch($type){
            case 'JPG':
                if ($save<>'') {
                    imagejpeg ($image, $save, 100); 
                }
            break;
            case 'PNG':
                if ($save<>'') {
                    imagepng ($image, $save, 9); 
                }
            break;
            default :
                     
            break;
        }
        imagedestroy($image); 
        imagedestroy($image_color);
        imagedestroy($image_tmp);
    }
    
    $urlfolder = "../app/uploads/payments/35763.jpg";
    
    $watermark = date("Y-m-d H:i:s"). " https://afx.trade #35763";
    
    addTextWatermark($urlfolder,$watermark,null,"../../../");
    
    header('Content-Type: image/jpeg');
    die();
    */
    /***
     * getnewaddress asignar un label para identificar las direcciones ejemplo "omniaddr" te permite trabajr multiples direcciones ("afxaddr")<-actual creados de prueba
     * getaddressesbylabel listar direcciones por label
     * omni_listtransactions puedes filtrar solo las transacciones de la cuenta con ese "label"
     * omni_send "address" amount ( "comment" "comment_to" subtractfeefromamount replaceable conf_target "estimate_mode") //Usable para retiros
     * omni_gettransaction "txid" consultar una transacción. 
     * omni_getwalletbalances devuelve el saldo general de la billetera en todas sus direcciones.
     * */
    //$mt = microtime(true);
    /*
    $parms = array('label'=>'afxaddr','count'=>100);
    $request = array('method'=>'listtransactions','parms' => $parms);
    $rest = json_decode(queryServicesBTC($BTC_URL, $request), true);*/
    //  b94b9c6df20cc08636006e0170865fedafa60793fe47979d470c942669cc458d
    /*
    function encrypt($string, $key) {
        $result = '';
        for($i=0; $i<strlen($string); $i++) {
            $char = substr($string, $i, 1);
            $keychar = substr($key, ($i % strlen($key))-1, 1);
            $char = chr(ord($char)+ord($keychar));
            $result.=$char;
        }
        return base64_encode($result);
    }
    $pwd = "D2bBKE39ED4Y42xiW8hmVS"."172.28.77.8";
    $key = "afxtrade"."172.28.77.8".$pwd;
    echo(encrypt($pwd,$key));
    die();
    */
    
    
    /*
    
function encrypt($string, $key) {
    $result = '';
    for($i=0; $i<strlen($string); $i++) {
        $char = substr($string, $i, 1);
        $keychar = substr($key, ($i % strlen($key))-1, 1);
        $char = chr(ord($char)+ord($keychar));
        $result.=$char;
    }
    return base64_encode($result);
}

    
    
    // Validamos que el error no sea nulo para mandar el mensaje
    if($rest['error'] != null){
        badEnd('500',array("msg"=>$rest['error']['message']));
    }*/
    
    // Validamos que el error no sea nulo para mandar el mensaje
    
    
    // Funcion para verificar depositos
/*
    $parms = array('label'=>'afxaddr','count'=>100);
    $request = array('method'=>'listtransactions','parms' => $parms);
    $rest = json_decode(queryServicesBTC($BTC_URL, $request), true);
    $out->entry2 [] = $rest;
    foreach($rest['result'] as $deposit){
        // Validamos que sea recibir dinero
        if($deposit['category'] == 'receive'){
            // SI es recibir, hacemos la busqueda
            //$out->entry2 [] = $deposit;
            $out->testing2 [] = date('Y-m-d H:i:s', $deposit['time'])."\n";
        }
    }
  
    // Funcion para realizar Retiros
    /*
    $parms = array('address'=>'bcrt1q4ajscmncqnes4pltevntyjf5a82c8dvxsd3rsy','amount'=>1);
    $request = array('method'=>'sendtoaddress','parms' => $parms);
    $rest = json_decode(queryServicesBTC($BTC_URL, $request), true);
    
    if($rest['error'] != null){
        badEnd('500',array("msg"=>$rest['error']['message']));
    }
    
    $out->entry = $rest;
    */
    // Funcion para verificar retiros
    /*
    $parms = array('txid'=>'99c75de0ea868082ac14dacd76b818099b988460cfdc0737baf9c57deca3185d');
    $request = array('method'=>'gettransaction','parms' => $parms);
    $rest = json_decode(queryServicesBTC($BTC_URL, $request), true);
    $out->entry = floatval($rest['result']['details'][0]['fee']);
    if($rest['details']['category'] == 'send'){
        
        // si es true es que ya fue abandonada y cancelada
        if($rest['details']['abandoned'] == true){
            
        }else{
            
        }
    }*/
    /*
    $parms = array('nblocks'=>5,'address'=>'bcrt1qrnck84qg9lz53emytkxnhalqcu3629k6rx85h6');
    $request = array('method'=>'generatetoaddress','parms' => $parms);
    $rest = json_decode(queryServicesBTC($BTC_URL, $request), true);
    $out->prueba = $rest;
    */
    
    header("HTTP/1.1 200");
    die();
    
?>

==> app25_06_2021_6:52pm.zip: app/api/deposits/testing.php <==
<?php

include("../../../settings/dbconn.php");
    include("../../../settings/utils.php");
    // app/api/deposits/testing
    /*
    header("Content-Type:application/json");
    include("../../../settings/dbconn.php");
    include("../../../settings/utils.php");
    $timezone = date_default_timezone_get();
   // date_default_timezone_set('Etc/UTC');
   $key = "172.28.77.8"."afxtrade"."AA2LtO6bIhov0exjxsX";
   echo encrypt("AA2LtO6bIhov0exjxsX",$key);
   function encrypt($string, $key) {
        $result = '';
        for($i=0; $i<strlen($string); $i++) {
            $char = substr($string, $i, 1);
            $keychar = substr($key, ($i % strlen($key))-1, 1);
            $char = chr(ord($char)+ord($keychar));
            $result.=$char;
        }
        return base64_encode($result);
    }
    die();
   */
   /*
   $url = "https://api.trongrid.io/v1/accounts/TL8TzvMqWWQG1G4d8D2c8vHTzPeSzjMBcr/transactions/trc20";
   function queryPublic($url, $type=false, array $request = array()){
    //Inicializamos el protocolo
    $curl = curl_init();
    curl_setopt_array($curl, array(
        CURLOPT_SSL_VERIFYPEER => true,
        CURLOPT_SSL_VERIFYHOST => 2,
        CURLOPT_USERAGENT => 'TCV PHP API Agent',
        CURLOPT_POST => true,
        CURLOPT_RETURNTRANSFER => true,
        CURLOPT_CONNECTTIMEOUT => 20,
        CURLOPT_TIMEOUT => 300)
    );

    // Parametros
    $postdata = http_build_query($request, '', '&');

    // llave de la api con su version
    $path = $url;
    // make request
    curl_setopt($curl, CURLOPT_URL, $url);
    curl_setopt($curl, CURLOPT_POSTFIELDS, $postdata);
    curl_setopt($curl, CURLOPT_HTTPHEADER, array());

    //si el type es true la llamada sera GET
    if($type){
        curl_setopt($curl, CURLOPT_URL, $url."?" . $postdata);
        curl_setopt($curl, CURLOPT_POST, false);
        curl_setopt($curl, CURLOPT_CUSTOMREQUEST, 'GET');
    }

    //Ejecutamos la llamada
    $result = curl_exec($curl);
    if ($result === false) {
        throw new \Exception('CURL error: ' . curl_error($curl));
    }

    // Comprueba el código de estado HTTP
    if (!curl_errno($curl)) {
        switch ($httpCode = curl_getinfo($curl, CURLINFO_HTTP_CODE)) {
                case 200: # OK
                break;
            default:
                echo 'HTTP code: ', $httpCode, "\n";
        }
    }
    $result = json_decode($result, true);

    curl_close($curl);

    return $result;
}
var_dump(queryPublic($url,true));
die();
   
   */
   
   
   /*
    function getUTCOffset($timezone, $colon=true)
    {
      $dtz = new DateTimeZone($timezone);
      $offset = $dtz->getOffset(new DateTime());
      $format=($colon)?'%+03d:%02u':'%+03d%02u';
    
      return sprintf($format, $offset / 3600, abs($offset) % 3600 / 60);
    }
    
    echo $timezone."\n";
    $zona = new DateTimeZone($timezone); 
    $fecha = microtime(true)+$zona->getOffset(new DateTime());
    echo $dateW = date("d/m/Y",$fecha)." - ".date("h:i:s a",$fecha)."\n";
    echo getUTCOffset('America/Caracas')."\n";
    echo getUTCOffset('Europe/Madrid', false)."\n";
    
    $file = "uploads/payments/35905.png";
    $zona = new DateTimeZone('America/Caracas'); 
    $fecha = microtime(true)+$zona->getOffset(new DateTime());
    $dateW = date("d/m/Y",$fecha)." - ".date("h:i:s a",$fecha);
    $watermark = $dateW. " https://afx.trade #".$txid;
    $save =  "../../../uploads/payments/35905.png";
    echo exif_imagetype("../../../uploads/payments/35905.png")."\n";
    echo (image_type_to_mime_type(exif_imagetype("../../../uploads/payments/35905.png")));
    addTextWatermark($file,$watermark,$save, "../../../");
    die();
    //include("../../../settings/utils.php");
    
    /***
     * getnewaddress asignar un label para identificar las direcciones ejemplo "afxusers" te permite trabajr multiples direcciones ("afxaddr")<-actual creados de prueba
     * getaddressesbylabel listar direcciones por label
     * listtransactions puedes filtrar solo las transacciones de la cuenta con ese "label"
     * sendtoaddress "address" amount ( "comment" "comment_to" subtractfeefromamount replaceable conf_target "estimate_mode") //Usable para retiros
     * gettransaction "txid" consultar una transacción. 
     * getbalance devuelve el saldo general de la billetera en todas sus direcciones.
     * */
    /*
    $nonce = generateNonce();
                    
                    // Llamamos a la api primerito
                    $request = array(
                        'banco'=>'0138',
                        'idBeneficiario'=>"V18184465",
                        'telefono'=>"4244445566",
                        'monto'=>(float)number_format(10000, 2, '.', ''),
                        'motivo'=>'Retiro AFX',
                        'canal'=>'23',
                    );
                    
                    $headers = array('Content-Type:application/json', 
                        "api-key: $BP_C2P_KEY", 
                        "api-signature: ".
                        (
                            generateApiSignature("/".$BP_VERSION_P2P."/pagos/p2p".$nonce.json_encode($request),$BP_C2P_KEY_SECRET)
                        ),
                        "nonce: ".$nonce,
                    );
                    // obtenemos respuesta
                    //$rest = queryApiBP($BP_URL_QA, "pagos/p2p", $BP_VERSION_P2P, "POST", $headers, $request);
                    //die(json_encode($rest));
    */
    /*
    function addTextWatermark($src, $watermark, $save=NULL) { 
         list($width, $height) = getimagesize($src);
         $image_color = imagecreatetruecolor($width, $height);
         $image_tmp = imagecreatetruecolor(740,50);
         $image = imagecreatefromjpeg($src);
         
         $logo = imagecreatefrompng('../../img/afx-logo.png');
         list($width2, $height2) = getimagesize('../../img/afx-logo.png');
         $txtcolor = imagecolorallocate($image_tmp, 255, 255, 255);
         $font = '../../fonts/roboto/Roboto-Black.ttf';
         $font_size = 20;
         
         imagecopyresampled($image_tmp, $logo, 25, 0, 0, -5, 60, 60, $width2, $height2);
         imagettftext($image_tmp, $font_size, 0, 90, 42.5, $txtcolor, $font, $watermark);
         
         $waterW = $width;
         $center = 0;
         if($waterW>740){
             $waterW=740;
             $center = ($width/2)-365;
         }
         
         
         
         imagecopyresampled($image_color, $image_tmp, $center, 0, 0, 0, $waterW, 50, 740, 50);
         imagesavealpha($image_color, true);
         
          $y =  rand(100, ($height-100));
         imagecopymerge($image,$image_color, 0, $y, 0, 0, $width, 60, 30);
         //imagecopyresampled($image_color, $image, 0, 0, 0, 0, $width, $height, $width, $height); 
         //imagestring($image_color, $font_size, 50, 350, $watermark, $txtcolor);
         if ($save<>'') {
            imagejpeg ($image_color, $save, 100); 
         } else {
             header('Content-Type: image/jpeg');
             imagejpeg($image, null, 100);
         }
         imagedestroy($image); 
         imagedestroy($image_color); 
    }*/
    /*
    function addTextWatermark($src, $watermark, $save=NULL,$url) { 
        list($width, $height) = getimagesize($src);
        $image_color = imagecreatetruecolor($width, $height);//Img base (marca de agua)
        $image_tmp = imagecreatetruecolor(740,50); //Marca de agua tamaño fijo
        $type = explode(".",$src);
        $type = strtoupper($type[1]);
        echo(var_dump(explode(".",$src)));
        die();
         //Se crea según su tipo
        switch($type){
            case 'JPG':
                $image = imagecreatefromjpeg($src); //img original
            break;
            case 'PNG':
                $image = imagecreatefrompng($src); //img original
            break;
            default :
                     
            break;
        }
         
        //Pinto el logo en el lado izquierdo e introduzco el texto a una imagen temporal.
        $logosrc = $url.'/img/afx-logo.png';
        $logo = imagecreatefrompng($logosrc);
        list($width2, $height2) = getimagesize($logosrc);
        $txtcolor = imagecolorallocate($image_tmp, 255, 255, 255);
        $font = $url.'/fonts/roboto/Roboto-Black.ttf';
        $font_size = 20;
        imagecopyresampled($image_tmp, $logo, 25, 0, 0, -5, 60, 60, $width2, $height2);
        imagettftext($image_tmp, $font_size, 0, 90, 42.5, $txtcolor, $font, $watermark);
         
        $waterW = $width;
        $center = 0;
         //Se calcula el tamaño de la imagen base (marca de agua) y se ubica la imagen creada en la marca de agua
        if($waterW>740){
            $waterW=740;
            $center = ($width/2)-365;
        }
        imagecopyresampled($image_color, $image_tmp, $center, 0, 0, 0, $waterW, 50, 740, 50);
        imagesavealpha($image_color, true);
         
        //Se Inserta la marca de agua a la imagen original del ancho completo y ubicación Y aleatroia sin llegar a los bordes (-100)
        $y =  rand(100, ($height-100));
        imagecopymerge($image,$image_color, 0, $y, 0, 0, $width, 60, 30);
        
         //Se guarda o no
        switch($type){
            case 'JPG':
                if ($save<>'') {
                    imagejpeg ($image, $save, 100); 
                }
            break;
            case 'PNG':
                if ($save<>'') {
                    imagepng ($image, $save, 9); 
                }
            break;
            default :
                     
            break;
        }
        imagedestroy($image); 
        imagedestroy($image_color);
        imagedestroy($image_tmp);
    }
    
    $urlfolder = "../app/uploads/payments/35763.jpg";
    
    $watermark = date("Y-m-d H:i:s"). " https://afx.trade #35763";
    
    addTextWatermark($urlfolder,$watermark,null,"../../../");
    
    header('Content-Type: image/jpeg');
    die();
    */
    /***
     * getnewaddress asignar un label para identificar las direcciones ejemplo "omniaddr" te permite trabajr multiples direcciones ("afxaddr")<-actual creados de prueba
     * getaddressesbylabel listar direcciones por label
     * omni_listtransactions puedes filtrar solo las transacciones de la cuenta con ese "label"
     * omni_send "address" amount ( "comment" "comment_to" subtractfeefromamount replaceable conf_target "estimate_mode") //Usable para retiros
     * omni_gettransaction "txid" consultar una transacción. 
     * omni_getwalletbalances devuelve el saldo general de la billetera en todas sus direcciones.
     * */
    //$mt = microtime(true);
    /*
    $parms = array('label'=>'afxaddr','count'=>100);
    $request = array('method'=>'listtransactions','parms' => $parms);
    $rest = json_decode(queryServicesBTC($BTC_URL, $request), true);*/
    //  b94b9c6df20cc08636006e0170865fedafa60793fe47979d470c942669cc458d
    $parms = array();
    $request = array('method'=>'getBalances', "address" => $USDT_CENTRAL_WALLET);
                $rest = json_decode(queryServicesUSDT($USDT_URL, $request), true);
    
    $out->entry = $rest;
    
    $out->entry2 = getUsdt();
    
    echo(json_encode($out));
    die();
    
    function formattUsdtAmount($value, $decimals){
        $amount = '';
        
        $begin = substr($value, 0, strlen($value)-$decimals);
        $end = substr($value, strlen($value)-$decimals);
        $amount = $begin.".".$end;
        
        return $amount;
    }
    
    function getUsdt(){
        return $USDT_URL;
    }
    
    /*
    
function encrypt($string, $key) {
    $result = '';
    for($i=0; $i<strlen($string); $i++) {
        $char = substr($string, $i, 1);
        $keychar = substr($key, ($i % strlen($key))-1, 1);
        $char = chr(ord($char)+ord($keychar));
        $result.=$char;
    }
    return base64_encode($result);
}

    
    
    // Validamos que el error no sea nulo para mandar el mensaje
    if($rest['error'] != null){
        badEnd('500',array("msg"=>$rest['error']['message']));
    }*/
    
    // Validamos que el error no sea nulo para mandar el mensaje
    
    
    // Funcion para verificar depositos
/*
    $parms = array('label'=>'afxaddr','count'=>100);
    $request = array('method'=>'listtransactions','parms' => $parms);
    $rest = json_decode(queryServicesBTC($BTC_URL, $request), true);
    $out->entry2 [] = $rest;
    foreach($rest['result'] as $deposit){
        // Validamos que sea recibir dinero
        if($deposit['category'] == 'receive'){
            // SI es recibir, hacemos la busqueda
            //$out->entry2 [] = $deposit;
            $out->testing2 [] = date('Y-m-d H:i:s', $deposit['time'])."\n";
        }
    }
  
    // Funcion para realizar Retiros
    /*
    $parms = array('address'=>'bcrt1q4ajscmncqnes4pltevntyjf5a82c8dvxsd3rsy','amount'=>1);
    $request = array('method'=>'sendtoaddress','parms' => $parms);
    $rest = json_decode(queryServicesBTC($BTC_URL, $request), true);
    
    if($rest['error'] != null){
        badEnd('500',array("msg"=>$rest['error']['message']));
    }
    
    $out->entry = $rest;
    */
    // Funcion para verificar retiros
    /*
    $parms = array('txid'=>'99c75de0ea868082ac14dacd76b818099b988460cfdc0737baf9c57deca3185d');
    $request = array('method'=>'gettransaction','parms' => $parms);
    $rest = json_decode(queryServicesBTC($BTC_URL, $request), true);
    $out->entry = floatval($rest['result']['details'][0]['fee']);
    if($rest['details']['category'] == 'send'){
        
        // si es true es que ya fue abandonada y cancelada
        if($rest['details']['abandoned'] == true){
            
        }else{
            
        }
    }*/
    /*
    $parms = array('nblocks'=>5,'address'=>'bcrt1qrnck84qg9lz53emytkxnhalqcu3629k6rx85h6');
    $request = array('method'=>'generatetoaddress','parms' => $parms);
    $rest = json_decode(queryServicesBTC($BTC_URL, $request), true);
    $out->prueba = $rest;
    */
    
    header("HTTP/1.1 200");
    echo(json_encode($out));
    die();
    
?>
